
# Type: material sample derivation association_object




URI: [biolink:material_sample_derivation_association_object](https://w3id.org/biolink/vocab/material_sample_derivation_association_object)


## Domain and Range

[MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md) ->  <sub>REQ</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md)
